@@ -36,7 +36,7 @@ DE_MAP_NAMES = {
     21: 'Migration',
     22: 'Rivers',
     23: 'Team Islands',
-    24: 'Random',
+    24: 'Full Random',
     25: 'Scandinavia',
     26: 'Mongolia',
     27: 'Yucatan',
@@ -45,9 +45,23 @@ DE_MAP_NAMES = {
     30: 'King of the Hill',
     31: 'Oasis',
     32: 'Ghost Lake',
-    33: 'Random Land Map',
+    33: 'Nomad',
+    49: 'Iberia',
+    50: 'Britain',
     51: 'Mideast',
-    # 59: Custom
+    52: 'Texas',
+    53: 'Italy',
+    54: 'Central America',
+    55: 'France',
+    56: 'Norse Lands',
+    57: 'Sea of Japan (East Sea)',
+    58: 'Byzantium',
+    59: 'Custom',
+    60: 'Random Land Map',
+    62: 'Random Real World Map',
+    63: 'Blind Random',
+    65: 'Random Special Map',
+    66: 'Random Special Map',
     67: 'Acropolis',
     68: 'Budapest',
     69: 'Cenotes',
@@ -64,13 +78,56 @@ DE_MAP_NAMES = {
     80: 'CtR Monsoon',
     81: 'CtR Pyramid Descent',
     82: 'CtR Spiral',
+    83: 'Kilimanjaro',
+    84: 'Mountain Pass',
+    85: 'Nile Delta',
     86: 'Serengeti',
+    87: 'Socotra',
+    88: 'Amazon',
+    89: 'China',
+    90: 'Horn of Africa',
+    91: 'India',
+    92: 'Madagascar',
+    93: 'West Africa',
+    94: 'Bohemia',
+    95: 'Earth',
+    96: 'Canyons',
+    97: 'Enemy Archipelago',
+    98: 'Enemy Islands',
+    99: 'Far Out',
+    100: 'Front Line',
+    101: 'Inner Circle',
+    102: 'Motherland',
+    103: 'Open Plains',
+    104: 'Ring of Water',
+    105: 'Snakepit',
+    106: 'The Eye',
+    107: 'Australia',
     108: 'Indochina',
+    109: 'Indonesia',
+    110: 'Strait of Malacca',
+    111: 'Philippines',
     112: 'Bog Islands',
+    113: 'Mangrove Jungle',
+    114: 'Pacific Islands',
+    115: 'Sandbank',
+    116: 'Water Nomad',
+    117: 'Jungle Islands',
+    118: 'Holy Line',
+    119: 'Border Stones',
+    120: 'Yin Yang',
+    121: 'Jungle Lanes',
     122: 'Alpine Lakes',
+    123: 'Bogland',
+    124: 'Mountain Ridge',
     125: 'Ravines',
+    126: 'Wolf Hill',
+    132: 'Antarctica',
+    137: 'Custom Map Pool',
     139: 'Golden Swamp',
-    140: 'Four Lakes'
+    140: 'Four Lakes',
+    141: 'Land Nomad',
+    145: 'Fall of Rome'
 }
 
 MAP_NAMES = {
