@@ -1,9 +1,18 @@
 """Chat Messages."""
+import json
 import logging
 from enum import Enum
 
 LOGGER = logging.getLogger(__name__)
-AGE_MARKER = 'advanced to the'
+AGE_MARKERS = [
+    'advanced to the',
+    'a progressé vers',
+    '升级至',
+    'avanzó a la',
+    'đã phát triển lên',
+    '시대로 발전했습니다',
+    'vorangeschritten'
+]
 SAVE_MARKERS = [
     'Continuar con la partida en vez de guardar y salir',
     'Voto iniciado para guardar y salir del juego',
@@ -25,7 +34,7 @@ class Chat(Enum):
     SAVE = 5
     MESSAGE = 6
     HELP = 7
-
+    DISCARD = 8
 
 def get_lobby_chat(header, encoding, diplomacy_type, players):
     """Get lobby chat."""
@@ -55,6 +64,10 @@ def parse_chat(line, encoding, timestamp, players, diplomacy_type=None, originat
         if line.find(save_marker) > 0:
             data['type'] = Chat.SAVE
             return data
+    for age_marker in AGE_MARKERS:
+        if line.find(age_marker) > 0:
+            data['type'] = Chat.AGE
+            return data
     if line.find('Voobly: Ratings provided') > 0:
         _parse_ladder(data, line)
     elif line.find('Voobly') == 3:
@@ -63,21 +76,41 @@ def parse_chat(line, encoding, timestamp, players, diplomacy_type=None, originat
         _parse_rating(data, line)
     elif line.find('@#0<') == 0:
         _parse_injected(data, line)
-    elif line.find(AGE_MARKER) > 0:
-        _parse_age_advance(data, line)
     elif line.find('--') == 3:
         _parse_help(data, line)
+    elif line.startswith('{"'):
+        _parse_json(data, line, diplomacy_type)
     else:
         _parse_chat(data, line, players, diplomacy_type)
+    if not _validate(data, players):
+        data['type'] = Chat.DISCARD
     return data
 
 
-def _parse_age_advance(data, line):
-    """Parse age advancement message."""
-    start = line.find(AGE_MARKER)
+def _validate(data, players):
+    """Chat messages can be bugged - check for invalid messages."""
+    numbers = [p['number'] for p in players]
+    if 'player_number' in data and data['player_number'] not in numbers:
+        return False
+    if data['timestamp'] > 0 and data['timestamp'] < 1000:
+        return False
+    return True
+
+
+def _parse_json(data, line, diplomacy_type):
+    """Parse DE JSON chat."""
+    payload = json.loads(line)
+    audience = 'team'
+    if payload['channel'] == 0:
+        if diplomacy_type == '1v1':
+            audience = 'all'
+    elif payload['channel'] == 1:
+        audience = 'all'
     data.update({
-        'type': Chat.AGE,
-        'age': line[start + len(AGE_MARKER) + 1:-1]
+        'type': Chat.MESSAGE,
+        'player_number': payload['player'],
+        'message': payload['message'],
+        'audience': audience
     })
 
 
