@@ -42,7 +42,10 @@ ENCODING_MARKERS = [
     ['地图类别：', 'cp936', 'zh'],
     ['地图类型：', 'GB2312', 'zh'],
     ['颌玉拙墁：', 'cp936', 'zh'],
-    ['位置：', 'utf-8', 'zh']
+    ['位置：', 'utf-8', 'zh'],
+    ['舞台: ', 'utf-8', 'zh'],
+    ['Vị trí: ', 'utf-8', 'vi'],
+    ['위치: ', 'utf-8', 'kr']
 ]
 LANGUAGE_MARKERS = [
     ['Dostepne', 'ISO-8859-2', 'pl'],
@@ -84,6 +87,8 @@ def extract_from_instructions(instructions):
             if instructions.find(pair[0].encode(pair[1])) > -1:
                 language = pair[2]
                 break
+    if encoding == 'unknown':
+        raise ValueError('could not detect encoding')
     return encoding, language, name
 
 
